@@ -79,6 +79,7 @@ class PCA:
         self.feature_importances_ = None #for scikit learn use with feature selection methods
         self.omega = None # scores covariance matrix for missing values score estimation
         self.training_scores = None
+        self._training_scores_stds = None
         self._chi2_params = []
 
     def fit(self, X, principal_components = None, cv_splits_number = 7, int_call = False):
@@ -192,11 +193,12 @@ class PCA:
             MatrixXModel = self.training_scores @ self.loadings 
             error = nan_to_num(X) - MatrixXModel
             SPE = sum(error ** 2 , axis = 1)
-            self._chi2_params.append((2 * mean(SPE) ** 2) / var(SPE)) #for future SPE analysis
+            self._chi2_params.append([mean(SPE), var(SPE)]) #for future SPE analysis
 
         if not int_call: 
             self.feature_importances_ = self._VIPs_calc(X,  principal_components = self.principal_components)
             self.omega = self.training_scores.T @ self.training_scores # calculation of the covariance matrix
+            self._training_scores_stds = std(self.training_scores, axis = 0)
         pass
         
     def predict(self, X, principal_components = None):
@@ -323,7 +325,7 @@ class PCA:
         
         scores_matrix = self.transform(X, principal_components = principal_components)
         
-        T2s = sum(scores_matrix / std(scores_matrix, axis = 0) ** 2, axis = 1)
+        T2s = sum((scores_matrix / self._training_scores_stds[:principal_components]) ** 2 , axis = 1)
         return T2s
     
     def T2_limit(self, alpha, principal_components = None):
@@ -396,8 +398,8 @@ class PCA:
         if isinstance(X, DataFrame) : X = X.to_numpy()
         
         scores = self.transform(X, principal_components = principal_components)
-        scores = (scores / scores.std(axis = 0) ) ** 2 
-        contributions = multiply(X, (scores @ self.loadings[:principal_components, :] ** 2) ** 1 / 2) 
+        scores = (scores / self._training_scores_stds[:principal_components]) ** 2 
+        contributions = multiply(X, (scores @ self.loadings[:principal_components, :] ** 2) ** (1 / 2)) 
 
         return contributions
        
@@ -473,8 +475,8 @@ class PCA:
         """
 
         if principal_components == None: principal_components = self.principal_components # Unless specified, the number of PCs is the one in the trained model 
-        
-        chi2_val = chi2.isf(1 - alpha, principal_components - 1)
-        SPE_limit = self._chi2_params[principal_components - 1] * chi2_val
+        chi2_df = 2 * self._chi2_params[principal_components - 1][0] ** 2 / self._chi2_params[principal_components - 1][1]
+        chi2_val = chi2.isf(1 - alpha, chi2_df)
+        SPE_limit = self._chi2_params[principal_components - 1][1] / (2 * self._chi2_params[principal_components - 1][0])  * chi2_val
         
         return SPE_limit
\ No newline at end of file
